"""
Pydantic schemas for message analyses.
"""
from datetime import datetime

from pydantic import BaseModel, Field


class AnalysisBase(BaseModel):
    """
    Base schema for message analyses.
    """
    analysis_text: str = Field(..., description="Text of the analysis")
    start_date: datetime = Field(..., description="Start date of the analysis period")
    end_date: datetime = Field(..., description="End date of the analysis period")


class AnalysisCreate(AnalysisBase):
    """
    Schema for creating a new analysis.
    """
    pass


class Analysis(AnalysisBase):
    """
    Schema for an analysis.
    """
    id: int
    created_at: datetime

    class Config:
        """
        Pydantic config for the Analysis schema.
        """
        from_attributes = True
